summaryrefslogtreecommitdiffstats
path: root/kcontrol/keys
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 04:10:07 +0000
commitfd3a982e26813f5bcc82c7e89ce6fa2ad44432bf (patch)
tree9eda848e56fcb862fdfdf479adeccd95b6fe387a /kcontrol/keys
parent02f67d0e1355b79b1806746efb0f2f640e57f13d (diff)
downloadtdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.tar.gz
tdebase-fd3a982e26813f5bcc82c7e89ce6fa2ad44432bf.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1212480 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kcontrol/keys')
-rw-r--r--kcontrol/keys/commandShortcuts.cpp4
-rwxr-xr-xkcontrol/keys/convertShortcuts.pl2
-rw-r--r--kcontrol/keys/kaccelaction.h4
-rw-r--r--kcontrol/keys/keyconfig.cpp10
-rw-r--r--kcontrol/keys/keys.desktop2
-rw-r--r--kcontrol/keys/modifiers.cpp2
-rw-r--r--kcontrol/keys/shortcuts.cpp18
-rw-r--r--kcontrol/keys/treeview.cpp12
8 files changed, 27 insertions, 27 deletions
diff --git a/kcontrol/keys/commandShortcuts.cpp b/kcontrol/keys/commandShortcuts.cpp
index edf285a5b..a38f46f29 100644
--- a/kcontrol/keys/commandShortcuts.cpp
+++ b/kcontrol/keys/commandShortcuts.cpp
@@ -83,13 +83,13 @@ void CommandShortcutsModule::initGUI()
label->setText(i18n("<qt>Below is a list of known commands which you may assign keyboard shortcuts to. "
"To edit, add or remove entries from this list use the "
"<a href=\"launchMenuEditor\">KDE menu editor</a>.</qt>"));
- label->tqsetSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Minimum);
+ label->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Minimum);
disconnect(label, TQT_SIGNAL(linkClicked(const TQString &)), label, TQT_SLOT(openLink(const TQString &)));
connect(label, TQT_SIGNAL(linkClicked(const TQString &)), this, TQT_SLOT(launchMenuEditor()));
mainLayout->addWidget(label);
m_tree = new AppTreeView(this, "appTreeView");
- m_tree->tqsetSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Expanding);
+ m_tree->setSizePolicy(TQSizePolicy::Preferred, TQSizePolicy::Expanding);
mainLayout->setStretchFactor(m_tree, 10);
mainLayout->addWidget(m_tree);
TQWhatsThis::add(m_tree,
diff --git a/kcontrol/keys/convertShortcuts.pl b/kcontrol/keys/convertShortcuts.pl
index fa189c810..9dc216ac6 100755
--- a/kcontrol/keys/convertShortcuts.pl
+++ b/kcontrol/keys/convertShortcuts.pl
@@ -9,7 +9,7 @@ foreach (<>) {
s/^Lock screen/Lock Session/;
s/^Lock Screen/Lock Session/;
s/^Mouse emulation/Mouse Emulation/;
- s/^Next keyboard tqlayout/Switch to Next Keyboard Layout/;
+ s/^Next keyboard layout/Switch to Next Keyboard Layout/;
s/Switch To Next Keyboard Layout/Switch to Next Keyboard Layout/;
s/^Screenshot of desktop/Desktop Screenshot/;
s/^Pop-up window operations menu/Window Operations Menu/;
diff --git a/kcontrol/keys/kaccelaction.h b/kcontrol/keys/kaccelaction.h
index faf6b6bd3..144427d9c 100644
--- a/kcontrol/keys/kaccelaction.h
+++ b/kcontrol/keys/kaccelaction.h
@@ -58,7 +58,7 @@ class KConfigBase;
1) KKey = "Meta+X"
1) Meta+X
2) KKey = "Asterisk"
- 1) Shift+8 (English tqlayout)
+ 1) Shift+8 (English layout)
2) Keypad_Asterisk
*/
@@ -111,7 +111,7 @@ class KAccelAction
bool setKeySequence( uint i, const KKeySequence& );
void clearShortcut();
- bool tqcontains( const KKeySequence& );
+ bool contains( const KKeySequence& );
TQString toString() const;
TQString toStringInternal() const;
diff --git a/kcontrol/keys/keyconfig.cpp b/kcontrol/keys/keyconfig.cpp
index a49eea231..09726de63 100644
--- a/kcontrol/keys/keyconfig.cpp
+++ b/kcontrol/keys/keyconfig.cpp
@@ -83,7 +83,7 @@ void KKeyModule::init( bool isGlobal, bool _bSeriesOnly, bool bSeriesNone )
kdDebug(125) << "sConfigKey: " << sConfigKey
<< " bIsNum: " << bIsNum
<< " bSeriesOnly: " << bSeriesOnly << endl;
- if( ((bSeriesOnly && !bIsNum) || (bSeriesNone && bIsNum)) && !sConfigKey.tqcontains( ':' ) ) {
+ if( ((bSeriesOnly && !bIsNum) || (bSeriesNone && bIsNum)) && !sConfigKey.contains( ':' ) ) {
actions.removeAction( sConfigKey );
i--;
}
@@ -170,7 +170,7 @@ void KKeyModule::init( bool isGlobal, bool _bSeriesOnly, bool bSeriesNone )
topLayout->addRowSpacing(3, 15);
topLayout->addMultiCellWidget(kc, 5, 5, 0, 1);
- setMinimumSize(topLayout->tqsizeHint());
+ setMinimumSize(topLayout->sizeHint());
}
KKeyModule::~KKeyModule (){
@@ -332,7 +332,7 @@ void KKeyModule::readScheme( int index )
TQString s = sFile.mid( ind, 1 );
s = s.upper();
- sFile.tqreplace( ind, 1, s );
+ sFile.replace( ind, 1, s );
}
@@ -416,8 +416,8 @@ void KKeyModule::readScheme( int index )
// Set various appropriate for the scheme
if ( indx < nSysSchemes ||
- (*sFileList->at(indx)).tqcontains( "/global-" ) ||
- (*sFileList->at(indx)).tqcontains( "/app-" ) ) {
+ (*sFileList->at(indx)).contains( "/global-" ) ||
+ (*sFileList->at(indx)).contains( "/app-" ) ) {
removeBt->setEnabled( FALSE );
} else {
removeBt->setEnabled( TRUE );
diff --git a/kcontrol/keys/keys.desktop b/kcontrol/keys/keys.desktop
index 9594b832a..b39bab385 100644
--- a/kcontrol/keys/keys.desktop
+++ b/kcontrol/keys/keys.desktop
@@ -179,7 +179,7 @@ Keywords[cs]=Klávesy,Globální klávesové zkratky,Schéma kláves,Klávesové
Keywords[csb]=Klawisze,globalné klawiszowé skrodzënë,schematë skrodzënów,sparłączenia klawiszów,skrodzënë dlô programów
Keywords[cy]=Bysell,Rhwymiadau bysell eang,Cynllun bysell,Llwybrau byr,Llwybrau byr y rhaglen
Keywords[da]=Taster,Globale tastebindinger,Tastesystem,Tastebindinger,genveje,programgenveje
-Keywords[de]=Tasten,Tastenzuordnung,Tastenkürzel,Kurzbefehle,Tastenschema,Tastaturtqlayout
+Keywords[de]=Tasten,Tastenzuordnung,Tastenkürzel,Kurzbefehle,Tastenschema,Tastaturlayout
Keywords[el]=Πλήκτρα,Καθολικοί συνδυασμοί πλήκτρων,Θέμα πλήκτρων,Συνδυασμοί πλήκτρων,συντομεύσεις,συντομεύσεις εφαρμογών
Keywords[eo]=klavoj,malloka,signifoj,asocioj,kombinoj,klavkombinoj
Keywords[es]=Teclas,Asociaciones de teclas globales,Esquema de teclas,Asociaciones de teclas,accesos directos,accesos directos de aplicaciones
diff --git a/kcontrol/keys/modifiers.cpp b/kcontrol/keys/modifiers.cpp
index 41e792d6f..d17e1619e 100644
--- a/kcontrol/keys/modifiers.cpp
+++ b/kcontrol/keys/modifiers.cpp
@@ -341,7 +341,7 @@ void ModifiersModule::slotMacSwapClicked()
if( m_pchkMacKeyboard->isChecked() && !KKeyNative::keyboardHasWinKey() ) {
KMessageBox::sorry( this,
i18n("You can only activate this option if your "
- "X keyboard tqlayout has the 'Super' or 'Meta' keys "
+ "X keyboard layout has the 'Super' or 'Meta' keys "
"properly configured as modifier keys."),
"Incompatibility" );
m_pchkMacSwap->setChecked( false );
diff --git a/kcontrol/keys/shortcuts.cpp b/kcontrol/keys/shortcuts.cpp
index 5db554ca6..9f997b7e5 100644
--- a/kcontrol/keys/shortcuts.cpp
+++ b/kcontrol/keys/shortcuts.cpp
@@ -145,7 +145,7 @@ void ShortcutsModule::initGUI()
m_pcbSchemes = new KComboBox( this );
m_pcbSchemes->setMinimumWidth( 100 );
- m_pcbSchemes->tqsetSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Fixed );
+ m_pcbSchemes->setSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Fixed );
connect( m_pcbSchemes, TQT_SIGNAL(activated(int)), TQT_SLOT(slotSelectScheme(int)) );
pHLayout->addWidget( m_pcbSchemes );
@@ -190,10 +190,10 @@ void ShortcutsModule::initGUI()
m_pListGeneral = new KAccelShortcutList( m_actionsGeneral, true );
m_pkcGeneral = new KKeyChooser( m_pListGeneral, this, KKeyChooser::Global, false );
- m_pkcGeneral->resize (m_pkcGeneral->tqsizeHint() );
+ m_pkcGeneral->resize (m_pkcGeneral->sizeHint() );
if (system("xmodmap 1> /dev/null 2> /dev/null") == 0) {
m_useRmWinKeys = new TQCheckBox( i18n("Use Win key as modifier (uncheck to bind Win key to Menu)"), this );
- m_useRmWinKeys->resize( m_useRmWinKeys->tqsizeHint() );
+ m_useRmWinKeys->resize( m_useRmWinKeys->sizeHint() );
m_useRmWinKeys->setChecked( m_bUseRmWinKeys );
pVLayout->addWidget( m_useRmWinKeys, 1, 0 );
connect( m_useRmWinKeys, TQT_SIGNAL(clicked()), TQT_SLOT(slotUseRmWinKeysClicked()) );
@@ -234,7 +234,7 @@ void ShortcutsModule::createActionsGeneral()
//kdDebug(125) << "sConfigKey: " << sConfigKey
// << " bIsNum: " << bIsNum << endl;
- if( bIsNum && !sConfigKey.tqcontains( ':' ) ) {
+ if( bIsNum && !sConfigKey.contains( ':' ) ) {
actions[i].setConfigurable( false );
actions[i].setName( TQString::null );
}
@@ -255,7 +255,7 @@ void ShortcutsModule::createActionsSequence()
//kdDebug(125) << "sConfigKey: " << sConfigKey
// << " bIsNum: " << bIsNum << endl;
- if( !bIsNum && !sConfigKey.tqcontains( ':' ) ) {
+ if( !bIsNum && !sConfigKey.contains( ':' ) ) {
actions[i].setConfigurable( false );
actions[i].setName( TQString::null );
}
@@ -327,14 +327,14 @@ void ShortcutsModule::slotSelectScheme( int )
config.setGroup( "Settings" );
//m_sBaseSchemeFile = config.readEntry( "Name" );
// If the user's keyboard tqlayout doesn't support the Win key,
// but this tqlayout scheme requires it,
if( !KKeyNative::keyboardHasWinKey()
&& config.readBoolEntry( "Uses Win Modifier", false ) ) {
// TODO: change "Win" to Win's label.
int ret = KMessageBox::warningContinueCancel( this,
i18n("This scheme requires the \"%1\" modifier key, which is not "
- "available on your keyboard tqlayout. Do you wish to view it anyway?" )
+ "available on your keyboard layout. Do you wish to view it anyway?" )
.arg(i18n("Win")) );
if( ret == KMessageBox::Cancel )
return;
@@ -384,7 +384,7 @@ void ShortcutsModule::slotSaveSchemeAs()
// Make the next letter upper case
TQString s = sFile.mid( ind, 1 );
s = s.upper();
- sFile.tqreplace( ind, 1, s );
+ sFile.replace( ind, 1, s );
}
iScheme = -1;
@@ -327,14 +327,14 @@ void ShortcutsModule::slotSelectScheme( int )
config.setGroup( "Settings" );
//m_sBaseSchemeFile = config.readEntry( "Name" );
- // If the user's keyboard tqlayout doesn't support the Win key,
- // but this tqlayout scheme requires it,
+ // If the user's keyboard layout doesn't support the Win key,
+ // but this layout scheme requires it,
if( !KKeyNative::keyboardHasWinKey()
&& config.readBoolEntry( "Uses Win Modifier", false ) ) {
diff --git a/kcontrol/keys/treeview.cpp b/kcontrol/keys/treeview.cpp
index 0d1ddc3cc..58de8a1f5 100644
--- a/kcontrol/keys/treeview.cpp
+++ b/kcontrol/keys/treeview.cpp
@@ -156,8 +156,8 @@ void AppTreeView::fillBranch(const TQString& rPath, AppTreeItem *parent)
TQString groupCaption = g->caption();
// Item names may contain ampersands. To avoid them being converted
- // to accelerators, tqreplace them with two ampersands.
- groupCaption.tqreplace("&", "&&");
+ // to accelerators, replace them with two ampersands.
+ groupCaption.replace("&", "&&");
AppTreeItem *item;
if (parent == 0)
@@ -177,8 +177,8 @@ void AppTreeView::fillBranch(const TQString& rPath, AppTreeItem *parent)
TQString serviceCaption = s->name();
// Item names may contain ampersands. To avoid them being converted
- // to accelerators, tqreplace them with two ampersands.
- serviceCaption.tqreplace("&", "&&");
+ // to accelerators, replace them with two ampersands.
+ serviceCaption.replace("&", "&&");
AppTreeItem* item;
if (parent == 0)
@@ -228,7 +228,7 @@ TQStringList AppTreeView::fileList(const TQString& rPath)
TQStringList files = dir.entryList();
for (TQStringList::ConstIterator it = files.begin(); it != files.end(); ++it) {
// does not work?!
- //if (filelist.tqcontains(*it)) continue;
+ //if (filelist.contains(*it)) continue;
if (relativePath.isEmpty()) {
filelist.remove(*it); // hack
@@ -266,7 +266,7 @@ TQStringList AppTreeView::dirList(const TQString& rPath)
for (TQStringList::ConstIterator it = subdirs.begin(); it != subdirs.end(); ++it) {
if ((*it) == "." || (*it) == "..") continue;
// does not work?!
- // if (dirlist.tqcontains(*it)) continue;
+ // if (dirlist.contains(*it)) continue;
if (relativePath.isEmpty()) {
dirlist.remove(*it); //hack